summaryrefslogtreecommitdiffstats
path: root/cpukit/posix/src/mqueuetimedreceive.c
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/posix/src/mqueuetimedreceive.c')
-rw-r--r--cpukit/posix/src/mqueuetimedreceive.c13
1 files changed, 6 insertions, 7 deletions
diff --git a/cpukit/posix/src/mqueuetimedreceive.c b/cpukit/posix/src/mqueuetimedreceive.c
index 3d433b3c61..19e5430ff2 100644
--- a/cpukit/posix/src/mqueuetimedreceive.c
+++ b/cpukit/posix/src/mqueuetimedreceive.c
@@ -41,10 +41,9 @@
#include <mqueue.h>
#include <rtems/system.h>
-#include <rtems/score/watchdog.h>
+#include <rtems/score/todimpl.h>
#include <rtems/seterr.h>
#include <rtems/posix/mqueueimpl.h>
-#include <rtems/posix/time.h>
/*
* 15.2.5 Receive a Message From a Message Queue, P1003.1b-1993, p. 279
@@ -62,7 +61,7 @@ ssize_t mq_timedreceive(
{
Watchdog_Interval ticks;
bool do_wait = true;
- POSIX_Absolute_timeout_conversion_results_t status;
+ TOD_Absolute_timeout_conversion_results status;
/*
* POSIX requires that blocking calls with timeouts that take
@@ -73,12 +72,12 @@ ssize_t mq_timedreceive(
* then we do a polling operation and convert the UNSATISFIED
* status into the appropriate error.
*
* If the status is POSIX_ABSOLUTE_TIMEOUT_INVALID,
* POSIX_ABSOLUTE_TIMEOUT_IS_IN_PAST, or POSIX_ABSOLUTE_TIMEOUT_IS_NOW,
* then we should not wait.
*/
- status = _POSIX_Absolute_timeout_to_ticks( abstime, &ticks );
- if ( status != POSIX_ABSOLUTE_TIMEOUT_IS_IN_FUTURE )
+ status = _TOD_Absolute_timeout_to_ticks( abstime, &ticks );
+ if ( status != TOD_ABSOLUTE_TIMEOUT_IS_IN_FUTURE )
do_wait = false;
return _POSIX_Message_queue_Receive_support(
@@ -73,12 +72,12 @@ ssize_t mq_timedreceive(
* status into the appropriate error.
*
- * If the status is POSIX_ABSOLUTE_TIMEOUT_INVALID,
- * POSIX_ABSOLUTE_TIMEOUT_IS_IN_PAST, or POSIX_ABSOLUTE_TIMEOUT_IS_NOW,
+ * If the status is TOD_ABSOLUTE_TIMEOUT_INVALID,
+ * TOD_ABSOLUTE_TIMEOUT_IS_IN_PAST, or TOD_ABSOLUTE_TIMEOUT_IS_NOW,
* then we should not wait.
*/